@@ -1,33 +1,20 @@
+use crate::ser::{Error, Result, Serializer};
 use serde::ser;
 
-use heapless::ArrayLength;
-
-use crate::ser::{Error, Result, Serializer};
-
 #[allow(clippy::module_name_repetitions)]
-pub struct SerializeStruct<'a, 'b, B, C>
-where
-    B: ArrayLength<u8>,
-    C: ArrayLength<u8>,
-{
+pub struct SerializeStruct<'a, 'b, const B: usize, const C: usize> {
     ser: &'a mut Serializer<'b, B, C>,
     first: bool,
 }
 
-impl<'a, 'b, B, C> SerializeStruct<'a, 'b, B, C>
-where
-    B: ArrayLength<u8>,
-    C: ArrayLength<u8>,
-{
+impl<'a, 'b, const B: usize, const C: usize> SerializeStruct<'a, 'b, B, C> {
     pub(crate) fn new(ser: &'a mut Serializer<'b, B, C>) -> Self {
         SerializeStruct { ser, first: true }
     }
 }
 
-impl<'a, 'b, B, C> ser::SerializeStruct for SerializeStruct<'a, 'b, B, C>
-where
-    B: ArrayLength<u8>,
-    C: ArrayLength<u8>,
+impl<'a, 'b, const B: usize, const C: usize> ser::SerializeStruct
+    for SerializeStruct<'a, 'b, B, C>
 {
     type Ok = ();
     type Error = Error;
